billing_associate_source_views: Associates one or more source billing views with an existing...

View source: R/billing_operations.R

billing_associate_source_viewsR Documentation

Associates one or more source billing views with an existing billing view

Description

Associates one or more source billing views with an existing billing view. This allows creating aggregate billing views that combine data from multiple sources.

See https://www.paws-r-sdk.com/docs/billing_associate_source_views/ for full documentation.

Usage

billing_associate_source_views(arn, sourceViews)

Arguments

arn

[required] The Amazon Resource Name (ARN) of the billing view to associate source views with.

sourceViews

[required] A list of ARNs of the source billing views to associate.


paws.cost.management documentation built on May 30, 2026, 9:09 a.m.