billing_disassociate_source_views: Removes the association between one or more source billing...

View source: R/billing_operations.R

billing_disassociate_source_viewsR Documentation

Removes the association between one or more source billing views and an existing billing view

Description

Removes the association between one or more source billing views and an existing billing view. This allows modifying the composition of aggregate billing views.

See https://www.paws-r-sdk.com/docs/billing_disassociate_source_views/ for full documentation.

Usage

billing_disassociate_source_views(arn, sourceViews)

Arguments

arn

[required] The Amazon Resource Name (ARN) of the billing view to disassociate source views from.

sourceViews

[required] A list of ARNs of the source billing views to disassociate.


paws.cost.management documentation built on May 30, 2026, 9:09 a.m.