View source: R/billing_operations.R
| billing_get_credits | R Documentation |
Returns the list of Amazon Web Services account credits for the specified account. Each credit includes its identifier, type, monetary amounts, applicable products, expiration, sharing configuration, and current enabled status.
See https://www.paws-r-sdk.com/docs/billing_get_credits/ for full documentation.
billing_get_credits(
accountId,
startDate,
endDate = NULL,
payerAccountFlag = NULL
)
accountId |
[required] The Amazon Web Services account ID. Must be a 12-digit numeric string. |
startDate |
[required] The start date for the credit period as Unix epoch seconds. Must be a past date that is not more than one year before the current date. |
endDate |
The end date for the credit period as Unix epoch seconds. Must not be a future date and must be on or after |
payerAccountFlag |
When |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.