billing_get_enterprise_support_charge_summary: Returns a summary of Enterprise Support data aggregated...

View source: R/billing_operations.R

billing_get_enterprise_support_charge_summaryR Documentation

Returns a summary of Enterprise Support data aggregated across all accounts in the Enterprise Support profile

Description

Returns a summary of Enterprise Support data aggregated across all accounts in the Enterprise Support profile.

See https://www.paws-r-sdk.com/docs/billing_get_enterprise_support_charge_summary/ for full documentation.

Usage

billing_get_enterprise_support_charge_summary(billingMonth)

Arguments

billingMonth

[required] The billing month in YYYY-MM format. This must be a month in the past.


paws.cost.management documentation built on Oct. 8, 2026, 1:08 a.m.