billing_list_billing_views: Lists the billing views available for a given time period

View source: R/billing_operations.R

billing_list_billing_viewsR Documentation

Lists the billing views available for a given time period

Description

Lists the billing views available for a given time period.

See https://www.paws-r-sdk.com/docs/billing_list_billing_views/ for full documentation.

Usage

billing_list_billing_views(
  activeTimeRange = NULL,
  arns = NULL,
  billingViewTypes = NULL,
  names = NULL,
  ownerAccountId = NULL,
  sourceAccountId = NULL,
  maxResults = NULL,
  nextToken = NULL
)

Arguments

activeTimeRange

The time range for the billing views listed. PRIMARY billing view is always listed. BILLING_GROUP billing views are listed for time ranges when the associated billing group resource in Billing Conductor is active. The time range must be within one calendar month.

arns

The Amazon Resource Name (ARN) that can be used to uniquely identify the billing view.

billingViewTypes

The type of billing view.

names

Filters the list of billing views by name. You can specify search criteria to match billing view names based on the search option provided.

ownerAccountId

The list of owners of the billing view.

sourceAccountId

Filters the results to include only billing views that use the specified account as a source.

maxResults

The maximum number of billing views to retrieve. Default is 100.

nextToken

The pagination token that is used on subsequent calls to list billing views.


paws.cost.management documentation built on May 30, 2026, 9:09 a.m.