billingconductor_batch_disas_resou_from_custo_line_item: Disassociates a batch of resources from a percentage custom...

billingconductor_batch_disassociate_resources_from_custom_line_itemR Documentation

Disassociates a batch of resources from a percentage custom line item

Description

Disassociates a batch of resources from a percentage custom line item.

See https://www.paws-r-sdk.com/docs/billingconductor_batch_disassociate_resources_from_custom_line_item/ for full documentation.

Usage

billingconductor_batch_disassociate_resources_from_custom_line_item(
  TargetArn,
  ResourceArns,
  BillingPeriodRange = NULL
)

Arguments

TargetArn

[required] A percentage custom line item ARN to disassociate the resources from.

ResourceArns

[required] A list containing the ARNs of resources to be disassociated.

BillingPeriodRange

A time range for which the margin summary is effective. The time range can be up to 12 months.


paws.cost.management documentation built on May 30, 2026, 9:09 a.m.