View source: R/billingconductor_operations.R
| billingconductor_create_billing_group | R Documentation |
Creates a billing group that resembles a consolidated billing family that Amazon Web Services charges, based off of the predefined pricing plan computation.
See https://www.paws-r-sdk.com/docs/billingconductor_create_billing_group/ for full documentation.
billingconductor_create_billing_group(
ClientToken = NULL,
Name,
AccountGrouping,
ComputationPreference,
PrimaryAccountId = NULL,
Description = NULL,
Tags = NULL
)
ClientToken |
A unique, case-sensitive identifier that you specify to ensure idempotency of the request. Idempotency ensures that an API request completes no more than one time. With an idempotent request, if the original request completes successfully, any subsequent retries complete successfully without performing any further actions. |
Name |
[required] The billing group name. The names must be unique. |
AccountGrouping |
[required] The set of accounts that will be under the billing group. The set of accounts resemble the linked accounts in a consolidated billing family. |
ComputationPreference |
[required] The preferences and settings that will be used to compute the Amazon Web Services charges for a billing group. |
PrimaryAccountId |
The account ID that serves as the main account in a billing group. |
Description |
The description of the billing group. |
Tags |
A map that contains tag keys and tag values that are attached to a billing group. This feature isn't available during the beta. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.