billingconductor_create_pricing_plan: Creates a pricing plan that is used for computing Amazon Web...

View source: R/billingconductor_operations.R

billingconductor_create_pricing_planR Documentation

Creates a pricing plan that is used for computing Amazon Web Services charges for billing groups

Description

Creates a pricing plan that is used for computing Amazon Web Services charges for billing groups.

See https://www.paws-r-sdk.com/docs/billingconductor_create_pricing_plan/ for full documentation.

Usage

billingconductor_create_pricing_plan(
  ClientToken = NULL,
  Name,
  Description = NULL,
  PricingRuleArns = NULL,
  Tags = NULL
)

Arguments

ClientToken

A unique, case-sensitive identifier that you specify to ensure idempotency of the request. Idempotency ensures that an API request completes no more than one time. With an idempotent request, if the original request completes successfully, any subsequent retries complete successfully without performing any further actions.

Name

[required] The name of the pricing plan. The names must be unique to each pricing plan.

Description

The description of the pricing plan.

PricingRuleArns

A list of Amazon Resource Names (ARNs) that define the pricing plan parameters.

Tags

A map that contains tag keys and tag values that are attached to a pricing plan.


paws.cost.management documentation built on May 30, 2026, 9:09 a.m.