View source: R/billingconductor_operations.R
| billingconductor_create_pricing_rule | R Documentation |
Creates a pricing rule can be associated to a pricing plan, or a set of pricing plans.
See https://www.paws-r-sdk.com/docs/billingconductor_create_pricing_rule/ for full documentation.
billingconductor_create_pricing_rule(
ClientToken = NULL,
Name,
Description = NULL,
Scope,
Type,
ModifierPercentage = NULL,
Service = NULL,
Tags = NULL,
BillingEntity = NULL,
Tiering = NULL,
UsageType = NULL,
Operation = NULL
)
ClientToken |
A unique, case-sensitive identifier that you specify to ensure idempotency of the request. Idempotency ensures that an API request completes no more than one time. With an idempotent request, if the original request completes successfully, any subsequent retries complete successfully without performing any further actions. |
Name |
[required] The pricing rule name. The names must be unique to each pricing rule. |
Description |
The pricing rule description. |
Scope |
[required] The scope of pricing rule that indicates if it's globally applicable, or it's service-specific. |
Type |
[required] The type of pricing rule. |
ModifierPercentage |
A percentage modifier that's applied on the public pricing rates. Your entry will be rounded to the nearest 2 decimal places. |
Service |
If the |
Tags |
A map that contains tag keys and tag values that are attached to a pricing rule. |
BillingEntity |
The seller of services provided by Amazon Web Services, their affiliates, or third-party providers selling services via Amazon Web Services Marketplace. |
Tiering |
The set of tiering configurations for the pricing rule. |
UsageType |
Usage type is the unit that each service uses to measure the usage of a specific type of resource. If the |
Operation |
Operation is the specific Amazon Web Services action covered by this line item. This describes the specific usage of the line item. If the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.