billingconductor_get_billing_transfer_preference: Retrieves the auto billing group creation preference for a...

View source: R/billingconductor_operations.R

billingconductor_get_billing_transfer_preferenceR Documentation

Retrieves the auto billing group creation preference for a billing transfer

Description

Retrieves the auto billing group creation preference for a billing transfer.

See https://www.paws-r-sdk.com/docs/billingconductor_get_billing_transfer_preference/ for full documentation.

Usage

billingconductor_get_billing_transfer_preference(ResponsibilityTransferArn)

Arguments

ResponsibilityTransferArn

[required] The Amazon Resource Name (ARN) of the billing transfer whose preference you want to retrieve.


paws.cost.management documentation built on Oct. 8, 2026, 1:08 a.m.