budgets_describe_budget: Describes a budget

View source: R/budgets_operations.R

budgets_describe_budgetR Documentation

Describes a budget

Description

Describes a budget.

See https://www.paws-r-sdk.com/docs/budgets_describe_budget/ for full documentation.

Usage

budgets_describe_budget(AccountId, BudgetName, ShowFilterExpression = NULL)

Arguments

AccountId

[required] The accountId that is associated with the budget that you want a description of.

BudgetName

[required] The name of the budget that you want a description of.

ShowFilterExpression

Specifies whether the response includes the filter expression associated with the budget. By showing the filter expression, you can see detailed filtering logic applied to the budget, such as Amazon Web Services services or tags that are being tracked.


paws.cost.management documentation built on May 30, 2026, 9:09 a.m.