budgets_describe_budget_notifications_for_account: Lists the budget names and notifications that are associated...

View source: R/budgets_operations.R

budgets_describe_budget_notifications_for_accountR Documentation

Lists the budget names and notifications that are associated with an account

Description

Lists the budget names and notifications that are associated with an account.

See https://www.paws-r-sdk.com/docs/budgets_describe_budget_notifications_for_account/ for full documentation.

Usage

budgets_describe_budget_notifications_for_account(
  AccountId,
  MaxResults = NULL,
  NextToken = NULL
)

Arguments

AccountId

[required] The account ID of the user. It's a 12-digit number.

MaxResults

An integer that represents how many budgets a paginated response contains. The default is 50.

NextToken

A generic string.


paws.cost.management documentation built on May 30, 2026, 9:09 a.m.