budgets_describe_budget_performance_history: Describes the history for DAILY, MONTHLY, and QUARTERLY...

View source: R/budgets_operations.R

budgets_describe_budget_performance_historyR Documentation

Describes the history for DAILY, MONTHLY, and QUARTERLY budgets

Description

Describes the history for DAILY, MONTHLY, and QUARTERLY budgets. Budget history isn't available for ANNUAL budgets.

See https://www.paws-r-sdk.com/docs/budgets_describe_budget_performance_history/ for full documentation.

Usage

budgets_describe_budget_performance_history(
  AccountId,
  BudgetName,
  TimePeriod = NULL,
  MaxResults = NULL,
  NextToken = NULL
)

Arguments

AccountId

[required] The account ID of the user. It's a 12-digit number.

BudgetName

[required] A string that represents the budget name. The ":" and "\" characters, and the "/action/" substring, aren't allowed.

Budget names are validated for content. Names that contain phone numbers, URLs, or email addresses combined with certain terms may be rejected.

TimePeriod

Retrieves how often the budget went into an ALARM state for the specified time period.

MaxResults

An integer that represents how many entries a paginated response contains. The maximum is 100.

NextToken

A generic string.


paws.cost.management documentation built on May 30, 2026, 9:09 a.m.