costexplorer_describe_cost_category_definition: Returns the name, Amazon Resource Name (ARN), rules,...

View source: R/costexplorer_operations.R

costexplorer_describe_cost_category_definitionR Documentation

Returns the name, Amazon Resource Name (ARN), rules, definition, and effective dates of a cost category that's defined in the account

Description

Returns the name, Amazon Resource Name (ARN), rules, definition, and effective dates of a cost category that's defined in the account.

See https://www.paws-r-sdk.com/docs/costexplorer_describe_cost_category_definition/ for full documentation.

Usage

costexplorer_describe_cost_category_definition(
  CostCategoryArn,
  EffectiveOn = NULL
)

Arguments

CostCategoryArn

[required] The unique identifier for your cost category.

EffectiveOn

The date when the cost category was effective.


paws.cost.management documentation built on May 30, 2026, 9:09 a.m.