Retrieves the cost anomaly subscription objects for your account. You can filter using a list of cost anomaly monitor Amazon Resource Names (ARNs).
See https://www.paws-r-sdk.com/docs/costexplorer_get_anomaly_subscriptions/ for full documentation.
costexplorer_get_anomaly_subscriptions(
SubscriptionArnList = NULL,
MonitorArn = NULL,
NextPageToken = NULL,
MaxResults = NULL
)A list of cost anomaly subscription ARNs.
Cost anomaly monitor ARNs.
The token to retrieve the next set of results. Amazon Web Services provides the token when the response from a previous call has more results than the maximum page size.
The number of entries a paginated response contains.