View source: R/marketplaceentitlementservice_operations.R
| marketplaceentitlementservice_get_entitlements | R Documentation |
GetEntitlements retrieves entitlement values for a given product. The results can be filtered based on customer identifier, AWS account ID, license ARN, or product dimensions.
See https://www.paws-r-sdk.com/docs/marketplaceentitlementservice_get_entitlements/ for full documentation.
marketplaceentitlementservice_get_entitlements(
ProductCode,
Filter = NULL,
NextToken = NULL,
MaxResults = NULL
)
ProductCode |
[required] Product code is used to uniquely identify a product in AWS Marketplace. The product code will be provided by AWS Marketplace when the product listing is created. |
Filter |
Filter is used to return entitlements for a specific customer or for a specific dimension. Filters are described as keys mapped to a lists of values. Filtered requests are unioned for each value in the value list, and then intersected for each filter key.
If you're migrating an existing integration, use Account Feeds to map |
NextToken |
For paginated calls to GetEntitlements, pass the NextToken from the previous GetEntitlementsResult. |
MaxResults |
The maximum number of items to retrieve from the GetEntitlements operation. For pagination, use the NextToken field in subsequent calls to GetEntitlements. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.