marketplacemetering_batch_meter_usage: Amazon Web Services Marketplace is introducing Concurrent...

View source: R/marketplacemetering_operations.R

marketplacemetering_batch_meter_usageR Documentation

Amazon Web Services Marketplace is introducing Concurrent Agreements, enabling buyers to make multiple purchases per Amazon Web Services account

Description

Amazon Web Services Marketplace is introducing Concurrent Agreements, enabling buyers to make multiple purchases per Amazon Web Services account. Starting June 1, 2026, new SaaS products must use CustomerAWSAccountId (instead of CustomerIdentifier), LicenseArn (instead of ProductCode) to support this feature. Existing integrations will continue to work. Review the new integration for Concurrent Agreements here.

See https://www.paws-r-sdk.com/docs/marketplacemetering_batch_meter_usage/ for full documentation.

Usage

marketplacemetering_batch_meter_usage(UsageRecords, ProductCode = NULL)

Arguments

UsageRecords

[required] The set of UsageRecords to submit. batch_meter_usage accepts up to 25 UsageRecords at a time.

ProductCode

Product code is used to uniquely identify a product in Amazon Web Services Marketplace. The product code should be the same as the one used during the publishing of a new product.


paws.cost.management documentation built on May 30, 2026, 9:09 a.m.