marketplacemetering_meter_usage: As a seller, your software hosted in the buyer's Amazon Web...

View source: R/marketplacemetering_operations.R

marketplacemetering_meter_usageR Documentation

As a seller, your software hosted in the buyer's Amazon Web Services account uses this API action to emit metering records directly to Amazon Web Services Marketplace

Description

As a seller, your software hosted in the buyer's Amazon Web Services account uses this API action to emit metering records directly to Amazon Web Services Marketplace. You must use the following buyer Amazon Web Services account credentials to sign the API request.

See https://www.paws-r-sdk.com/docs/marketplacemetering_meter_usage/ for full documentation.

Usage

marketplacemetering_meter_usage(
  ProductCode,
  Timestamp,
  UsageDimension,
  UsageQuantity = NULL,
  DryRun = NULL,
  UsageAllocations = NULL,
  ClientToken = NULL
)

Arguments

ProductCode

[required] Product code is used to uniquely identify a product in Amazon Web Services Marketplace. The product code should be the same as the one used during the publishing of a new product.

Timestamp

[required] Timestamp, in UTC, for which the usage is being reported. Your application can meter usage for up to six hours in the past. Make sure the timestamp value is not before the start of the software usage.

UsageDimension

[required] It will be one of the fcp dimension name provided during the publishing of the product.

UsageQuantity

Consumption value for the hour. Defaults to 0 if not specified.

DryRun

Checks whether you have the permissions required for the action, but does not make the request. If you have the permissions, the request returns DryRunOperation; otherwise, it returns UnauthorizedException. Defaults to false if not specified.

UsageAllocations

The set of UsageAllocations to submit.

The sum of all UsageAllocation quantities must equal the UsageQuantity of the meter_usage request, and each UsageAllocation must have a unique set of tags (include no tags).

ClientToken

Specifies a unique, case-sensitive identifier that you provide to ensure the idempotency of the request. This lets you safely retry the request without accidentally performing the same operation a second time. Passing the same value to a later call to an operation requires that you also pass the same value for all other parameters. We recommend that you use a UUID type of value.

If you don't provide this value, then Amazon Web Services generates a random one for you.

If you retry the operation with the same ClientToken, but with different parameters, the retry fails with an IdempotencyConflictException error.


paws.cost.management documentation built on May 30, 2026, 9:09 a.m.