paymentcryptographycontrolplane_associate_mpa_team: Associates a Multi-Party Approval (MPA) team with a protected...

View source: R/paymentcryptographycontrolplane_operations.R

paymentcryptographycontrolplane_associate_mpa_teamR Documentation

Associates a Multi-Party Approval (MPA) team with a protected operation

Description

Associates a Multi-Party Approval (MPA) team with a protected operation. For more information, see Multi-Party Approval in the Amazon Web Services Payment Cryptography User Guide.

See https://www.paws-r-sdk.com/docs/paymentcryptographycontrolplane_associate_mpa_team/ for full documentation.

Usage

paymentcryptographycontrolplane_associate_mpa_team(
  Action,
  MpaTeamArn,
  RequesterComment = NULL
)

Arguments

Action

[required] The protected operation to associate with the MPA team. Currently, the only supported value is IMPORT_ROOT_PUBLIC_KEY_CERTIFICATE.

MpaTeamArn

[required] The ARN of the MPA team to associate with the protected operation.

RequesterComment

The comment from the requester explaining the reason for the association.

Don't include personal, confidential or sensitive information in this field. This field may be displayed in plaintext in CloudTrail logs and other output.


paws.cost.management documentation built on May 30, 2026, 9:09 a.m.