paymentcryptographycontrolplane_delete_resource_policy: Removes the resource-based policy attached to an Amazon Web...

View source: R/paymentcryptographycontrolplane_operations.R

paymentcryptographycontrolplane_delete_resource_policyR Documentation

Removes the resource-based policy attached to an Amazon Web Services Payment Cryptography key

Description

Removes the resource-based policy attached to an Amazon Web Services Payment Cryptography key.

See https://www.paws-r-sdk.com/docs/paymentcryptographycontrolplane_delete_resource_policy/ for full documentation.

Usage

paymentcryptographycontrolplane_delete_resource_policy(ResourceArn)

Arguments

ResourceArn

[required] The KeyARN of the key whose resource-based policy you want to delete.


paws.cost.management documentation built on May 30, 2026, 9:09 a.m.