paymentcryptographycontrolplane_dis_def_key_rep_reg: Disables Multi-Region key replication settings for the...

paymentcryptographycontrolplane_disable_default_key_replication_regionsR Documentation

Disables Multi-Region key replication settings for the specified Amazon Web Services Regions in your Amazon Web Services account, preventing new keys from being automatically replicated to those regions

Description

Disables Multi-Region key replication settings for the specified Amazon Web Services Regions in your Amazon Web Services account, preventing new keys from being automatically replicated to those regions.

See https://www.paws-r-sdk.com/docs/paymentcryptographycontrolplane_disable_default_key_replication_regions/ for full documentation.

Usage

paymentcryptographycontrolplane_disable_default_key_replication_regions(
  ReplicationRegions
)

Arguments

ReplicationRegions

[required] The list of Amazon Web Services Regions to remove from the account's default replication regions.

New keys created after this operation will not automatically be replicated to these regions, though existing keys with replication to these regions will be unaffected.


paws.cost.management documentation built on May 30, 2026, 9:09 a.m.