paymentcryptographycontrolplane_disassociate_mpa_team: Removes the association between a Multi-Party Approval (MPA)...

View source: R/paymentcryptographycontrolplane_operations.R

paymentcryptographycontrolplane_disassociate_mpa_teamR Documentation

Removes the association between a Multi-Party Approval (MPA) team and a protected operation

Description

Removes the association between a Multi-Party Approval (MPA) team and a protected operation.

See https://www.paws-r-sdk.com/docs/paymentcryptographycontrolplane_disassociate_mpa_team/ for full documentation.

Usage

paymentcryptographycontrolplane_disassociate_mpa_team(
  Action,
  RequesterComment = NULL
)

Arguments

Action

[required] The protected operation to disassociate from the MPA team. Currently, the only supported value is IMPORT_ROOT_PUBLIC_KEY_CERTIFICATE.

RequesterComment

The comment from the requester explaining the reason for the disassociation.

Don't include personal, confidential or sensitive information in this field. This field may be displayed in plaintext in CloudTrail logs and other output.


paws.cost.management documentation built on May 30, 2026, 9:09 a.m.