paymentcryptographycontrolplane_ena_def_key_rep_reg: Enables Multi-Region key replication settings for your Amazon...

paymentcryptographycontrolplane_enable_default_key_replication_regionsR Documentation

Enables Multi-Region key replication settings for your Amazon Web Services account, causing new keys to be automatically replicated to the specified Amazon Web Services Regions when created

Description

Enables Multi-Region key replication settings for your Amazon Web Services account, causing new keys to be automatically replicated to the specified Amazon Web Services Regions when created.

See https://www.paws-r-sdk.com/docs/paymentcryptographycontrolplane_enable_default_key_replication_regions/ for full documentation.

Usage

paymentcryptographycontrolplane_enable_default_key_replication_regions(
  ReplicationRegions
)

Arguments

ReplicationRegions

[required] The list of Amazon Web Services Regions to enable as default replication regions for the Amazon Web Services account for Multi-Region key replication.

New keys created in this account will automatically be replicated to these regions unless explicitly overridden during key creation.


paws.cost.management documentation built on May 30, 2026, 9:09 a.m.