paymentcryptographycontrolplane_get_def_key_rep_reg: Retrieves the list of Amazon Web Services Regions where...

paymentcryptographycontrolplane_get_default_key_replication_regionsR Documentation

Retrieves the list of Amazon Web Services Regions where Multi-Region key replication is currently enabled for your Amazon Web Services account

Description

Retrieves the list of Amazon Web Services Regions where Multi-Region key replication is currently enabled for your Amazon Web Services account.

See https://www.paws-r-sdk.com/docs/paymentcryptographycontrolplane_get_default_key_replication_regions/ for full documentation.

Usage

paymentcryptographycontrolplane_get_default_key_replication_regions()

paws.cost.management documentation built on May 30, 2026, 9:09 a.m.