paymentcryptographycontrolplane_get_key: Gets the key metadata for an Amazon Web Services Payment...

View source: R/paymentcryptographycontrolplane_operations.R

paymentcryptographycontrolplane_get_keyR Documentation

Gets the key metadata for an Amazon Web Services Payment Cryptography key, including the immutable and mutable attributes specified when the key was created

Description

Gets the key metadata for an Amazon Web Services Payment Cryptography key, including the immutable and mutable attributes specified when the key was created. Returns key metadata including attributes, state, and timestamps, but does not return the actual cryptographic key material.

See https://www.paws-r-sdk.com/docs/paymentcryptographycontrolplane_get_key/ for full documentation.

Usage

paymentcryptographycontrolplane_get_key(KeyIdentifier)

Arguments

KeyIdentifier

[required] The KeyARN of the Amazon Web Services Payment Cryptography key.


paws.cost.management documentation built on May 30, 2026, 9:09 a.m.