paymentcryptographycontrolplane_get_parameters_for_export: Gets the export token and the signing key certificate to...

View source: R/paymentcryptographycontrolplane_operations.R

paymentcryptographycontrolplane_get_parameters_for_exportR Documentation

Gets the export token and the signing key certificate to initiate a TR-34 key export from Amazon Web Services Payment Cryptography

Description

Gets the export token and the signing key certificate to initiate a TR-34 key export from Amazon Web Services Payment Cryptography.

See https://www.paws-r-sdk.com/docs/paymentcryptographycontrolplane_get_parameters_for_export/ for full documentation.

Usage

paymentcryptographycontrolplane_get_parameters_for_export(
  KeyMaterialType,
  SigningKeyAlgorithm,
  ReuseLastGeneratedToken = NULL
)

Arguments

KeyMaterialType

[required] The key block format type (for example, TR-34 or TR-31) to use during key material export. Export token is only required for a TR-34 key export, TR34_KEY_BLOCK. Export token is not required for TR-31 key export.

SigningKeyAlgorithm

[required] The signing key algorithm to generate a signing key certificate. This certificate signs the wrapped key under export within the TR-34 key block. RSA_2048 is the only signing key algorithm allowed.

ReuseLastGeneratedToken

Specifies whether to reuse the existing export token and signing key certificate. If set to true and a valid export token exists for the same key material type and signing key algorithm with at least 7 days of remaining validity, the existing token and signing key certificate are returned. Otherwise, a new export token and signing key certificate are generated. The default value is false, which generates a new export token and signing key certificate on every call.


paws.cost.management documentation built on May 30, 2026, 9:09 a.m.