paymentcryptographycontrolplane_get_parameters_for_import: Gets the import token and the wrapping key certificate in PEM...

View source: R/paymentcryptographycontrolplane_operations.R

paymentcryptographycontrolplane_get_parameters_for_importR Documentation

Gets the import token and the wrapping key certificate in PEM format (base64 encoded) to initiate a TR-34 WrappedKeyBlock or a RSA WrappedKeyCryptogram import into Amazon Web Services Payment Cryptography

Description

Gets the import token and the wrapping key certificate in PEM format (base64 encoded) to initiate a TR-34 WrappedKeyBlock or a RSA WrappedKeyCryptogram import into Amazon Web Services Payment Cryptography.

See https://www.paws-r-sdk.com/docs/paymentcryptographycontrolplane_get_parameters_for_import/ for full documentation.

Usage

paymentcryptographycontrolplane_get_parameters_for_import(
  KeyMaterialType,
  WrappingKeyAlgorithm,
  ReuseLastGeneratedToken = NULL
)

Arguments

KeyMaterialType

[required] The method to use for key material import. Import token is only required for TR-34 WrappedKeyBlock (TR34_KEY_BLOCK) and RSA WrappedKeyCryptogram (KEY_CRYPTOGRAM).

Import token is not required for TR-31, root public key cerificate or trusted public key certificate.

WrappingKeyAlgorithm

[required] The wrapping key algorithm to generate a wrapping key certificate. This certificate wraps the key under import.

At this time, RSA_2048 is the allowed algorithm for TR-34 WrappedKeyBlock import. Additionally, RSA_2048, RSA_3072, RSA_4096 are the allowed algorithms for RSA WrappedKeyCryptogram import.

ReuseLastGeneratedToken

Specifies whether to reuse the existing import token and wrapping key certificate. If set to true and a valid import token exists for the same key material type and wrapping key algorithm with at least 7 days of remaining validity, the existing token and wrapping key certificate are returned. Otherwise, a new import token and wrapping key certificate are generated. The default value is false, which generates a new import token and wrapping key certificate on every call.


paws.cost.management documentation built on May 30, 2026, 9:09 a.m.