paymentcryptographycontrolplane_put_resource_policy: Attaches or replaces a resource-based policy on an Amazon Web...

View source: R/paymentcryptographycontrolplane_operations.R

paymentcryptographycontrolplane_put_resource_policyR Documentation

Attaches or replaces a resource-based policy on an Amazon Web Services Payment Cryptography key

Description

Attaches or replaces a resource-based policy on an Amazon Web Services Payment Cryptography key. A resource-based policy can grant cross-account access to your key.

See https://www.paws-r-sdk.com/docs/paymentcryptographycontrolplane_put_resource_policy/ for full documentation.

Usage

paymentcryptographycontrolplane_put_resource_policy(ResourceArn, Policy)

Arguments

ResourceArn

[required] The KeyARN of the key to attach the resource-based policy to.

Policy

[required] The resource-based policy to attach to the key, in JSON format.


paws.cost.management documentation built on May 30, 2026, 9:09 a.m.