paymentcryptographydataplane_gene_auth_requ_cryp: Generates an Authorization Request Cryptogram (ARQC) for an...

paymentcryptographydataplane_generate_auth_request_cryptogramR Documentation

Generates an Authorization Request Cryptogram (ARQC) for an EMV chip payment card authorization

Description

Generates an Authorization Request Cryptogram (ARQC) for an EMV chip payment card authorization. For more information, see Generate auth request cryptogram in the Amazon Web Services Payment Cryptography User Guide.

See https://www.paws-r-sdk.com/docs/paymentcryptographydataplane_generate_auth_request_cryptogram/ for full documentation.

Usage

paymentcryptographydataplane_generate_auth_request_cryptogram(
  KeyIdentifier,
  TransactionData,
  MajorKeyDerivationMode,
  SessionKeyDerivationAttributes
)

Arguments

KeyIdentifier

[required] The keyARN of the IMK-AC (TR31_E0_EMV_MKEY_APP_CRYPTOGRAMS) that Amazon Web Services Payment Cryptography uses to generate the ARQC.

TransactionData

[required] The transaction data that Amazon Web Services Payment Cryptography uses for ARQC generation. The same transaction data is used for ARQC verification by the issuer using verify_auth_request_cryptogram.

MajorKeyDerivationMode

[required] The method to use when deriving the major encryption key for ARQC generation within Amazon Web Services Payment Cryptography.

SessionKeyDerivationAttributes

[required] The attributes and values to use for deriving a session key for ARQC generation within Amazon Web Services Payment Cryptography.


paws.cost.management documentation built on May 30, 2026, 9:09 a.m.