paymentcryptographydataplane_generate_as_2805_kek_validation: Generates a KekValidationRequest or a KekValidationResponse...

View source: R/paymentcryptographydataplane_operations.R

paymentcryptographydataplane_generate_as_2805_kek_validationR Documentation

Generates a KekValidationRequest or a KekValidationResponse for node-to-node initialization between payment processing nodes using Australian Standard 2805 (AS2805)

Description

Generates a KekValidationRequest or a KekValidationResponse for node-to-node initialization between payment processing nodes using Australian Standard 2805 (AS2805).

See https://www.paws-r-sdk.com/docs/paymentcryptographydataplane_generate_as_2805_kek_validation/ for full documentation.

Usage

paymentcryptographydataplane_generate_as_2805_kek_validation(
  KeyIdentifier,
  KekValidationType,
  RandomKeySendVariantMask
)

Arguments

KeyIdentifier

[required] The keyARN of sending KEK that Amazon Web Services Payment Cryptography uses for node-to-node initialization

KekValidationType

[required] Defines whether to generate a KEK validation request or KEK validation response for node-to-node initialization.

RandomKeySendVariantMask

[required] The key variant to use for generating a random key for KEK validation during node-to-node initialization.


paws.cost.management documentation built on May 30, 2026, 9:09 a.m.