paymentcryptographydataplane_translate_key_material: Translates an cryptographic key between different wrapping...

View source: R/paymentcryptographydataplane_operations.R

paymentcryptographydataplane_translate_key_materialR Documentation

Translates an cryptographic key between different wrapping keys without importing the key into Amazon Web Services Payment Cryptography

Description

Translates an cryptographic key between different wrapping keys without importing the key into Amazon Web Services Payment Cryptography.

See https://www.paws-r-sdk.com/docs/paymentcryptographydataplane_translate_key_material/ for full documentation.

Usage

paymentcryptographydataplane_translate_key_material(
  IncomingKeyMaterial,
  OutgoingKeyMaterial,
  KeyCheckValueAlgorithm = NULL
)

Arguments

IncomingKeyMaterial

[required] Parameter information of the TR31WrappedKeyBlock containing the transaction key.

OutgoingKeyMaterial

[required] Parameter information of the wrapping key used to wrap the transaction key in the outgoing TR31WrappedKeyBlock.

KeyCheckValueAlgorithm

The key check value (KCV) algorithm used for calculating the KCV of the derived key.


paws.cost.management documentation built on May 30, 2026, 9:09 a.m.