View source: R/billing_operations.R
| billing_associate_source_views | R Documentation |
Associates one or more source billing views with an existing billing view. This allows creating aggregate billing views that combine data from multiple sources.
See https://www.paws-r-sdk.com/docs/billing_associate_source_views/ for full documentation.
billing_associate_source_views(arn, sourceViews)
arn |
[required] The Amazon Resource Name (ARN) of the billing view to associate source views with. |
sourceViews |
[required] A list of ARNs of the source billing views to associate. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.