View source: R/billing_operations.R
| billing_list_billing_view_segments | R Documentation |
Lists the segments of a billing view over a given time period. Each segment identifies the billing domain (PRO_FORMA or BILLABLE) and the account relationships that apply during its time range.
See https://www.paws-r-sdk.com/docs/billing_list_billing_view_segments/ for full documentation.
billing_list_billing_view_segments(
timeRange = NULL,
arn = NULL,
maxResults = NULL,
nextToken = NULL
)
timeRange |
The billing period to query. If you don't provide a time range, the current billing period, which is the calendar month in UTC, is used. |
arn |
The Amazon Resource Name (ARN) that uniquely identifies the billing view to query. If you don't provide an ARN, the caller's |
maxResults |
The number of entries a paginated response contains. Valid values range from 1 to 100. The default is 100. |
nextToken |
The pagination token that is used on subsequent calls to list billing view segments. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.