View source: R/billingconductor_operations.R
| billingconductor_get_billing_transfer_preference | R Documentation |
Retrieves the auto billing group creation preference for a billing transfer.
See https://www.paws-r-sdk.com/docs/billingconductor_get_billing_transfer_preference/ for full documentation.
billingconductor_get_billing_transfer_preference(ResponsibilityTransferArn)
ResponsibilityTransferArn |
[required] The Amazon Resource Name (ARN) of the billing transfer whose preference you want to retrieve. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.