View source: R/budgets_operations.R
| budgets_create_budget_action | R Documentation |
Creates a budget action.
See https://www.paws-r-sdk.com/docs/budgets_create_budget_action/ for full documentation.
budgets_create_budget_action(
AccountId,
BudgetName,
NotificationType,
ActionType,
ActionThreshold,
Definition,
ExecutionRoleArn,
ApprovalModel,
Subscribers,
ResourceTags = NULL
)
AccountId |
[required] The account ID of the user. It's a 12-digit number. |
BudgetName |
[required] A string that represents the budget name. The ":" and "\" characters, and the "/action/" substring, aren't allowed. Budget names are validated for content. Names that contain phone numbers, URLs, or email addresses combined with certain terms may be rejected. |
NotificationType |
[required] The type of a notification. It must be ACTUAL or FORECASTED. |
ActionType |
[required] The type of action. This defines the type of tasks that can be carried out by this action. This field also determines the format for definition. |
ActionThreshold |
[required] The trigger threshold of the action. |
Definition |
[required] Specifies all of the type-specific parameters. |
ExecutionRoleArn |
[required] The role passed for action execution and reversion. Roles and actions must be in the same account. |
ApprovalModel |
[required] This specifies if the action needs manual or automatic approval. |
Subscribers |
[required] A list of subscribers. |
ResourceTags |
An optional list of tags to associate with the specified budget action. Each tag consists of a key and a value, and each key must be unique for the resource. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.