View source: R/budgets_operations.R
| budgets_describe_budget | R Documentation |
Describes a budget.
See https://www.paws-r-sdk.com/docs/budgets_describe_budget/ for full documentation.
budgets_describe_budget(AccountId, BudgetName, ShowFilterExpression = NULL)
AccountId |
[required] The |
BudgetName |
[required] The name of the budget that you want a description of. |
ShowFilterExpression |
Specifies whether the response includes the filter expression associated with the budget. By showing the filter expression, you can see detailed filtering logic applied to the budget, such as Amazon Web Services services or tags that are being tracked. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.