View source: R/budgets_operations.R
| budgets_describe_budget_action_histories | R Documentation |
Describes a budget action history detail.
See https://www.paws-r-sdk.com/docs/budgets_describe_budget_action_histories/ for full documentation.
budgets_describe_budget_action_histories(
AccountId,
BudgetName,
ActionId,
TimePeriod = NULL,
MaxResults = NULL,
NextToken = NULL
)
AccountId |
[required] The account ID of the user. It's a 12-digit number. |
BudgetName |
[required] A string that represents the budget name. The ":" and "\" characters, and the "/action/" substring, aren't allowed. Budget names are validated for content. Names that contain phone numbers, URLs, or email addresses combined with certain terms may be rejected. |
ActionId |
[required] A system-generated universally unique identifier (UUID) for the action. |
TimePeriod |
The period of time that's covered by a budget. The period has a start date and an end date. The start date must come before the end date. There are no restrictions on the end date. |
MaxResults |
An integer that represents how many entries a paginated response contains. The maximum is 100. |
NextToken |
A generic string. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.