View source: R/budgets_operations.R
| budgets_update_budget_action | R Documentation |
Updates a budget action.
See https://www.paws-r-sdk.com/docs/budgets_update_budget_action/ for full documentation.
budgets_update_budget_action(
AccountId,
BudgetName,
ActionId,
NotificationType = NULL,
ActionThreshold = NULL,
Definition = NULL,
ExecutionRoleArn = NULL,
ApprovalModel = NULL,
Subscribers = NULL
)
AccountId |
[required] The account ID of the user. It's a 12-digit number. |
BudgetName |
[required] A string that represents the budget name. The ":" and "\" characters, and the "/action/" substring, aren't allowed. Budget names are validated for content. Names that contain phone numbers, URLs, or email addresses combined with certain terms may be rejected. |
ActionId |
[required] A system-generated universally unique identifier (UUID) for the action. |
NotificationType |
The type of a notification. It must be ACTUAL or FORECASTED. |
ActionThreshold |
The trigger threshold of the action. |
Definition |
Specifies all of the type-specific parameters. |
ExecutionRoleArn |
The role passed for action execution and reversion. Roles and actions must be in the same account. |
ApprovalModel |
This specifies if the action needs manual or automatic approval. |
Subscribers |
A list of subscribers. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.