View source: R/costandusagereportservice_operations.R
| costandusagereportservice_modify_report_definition | R Documentation |
Allows you to programmatically update your report preferences.
See https://www.paws-r-sdk.com/docs/costandusagereportservice_modify_report_definition/ for full documentation.
costandusagereportservice_modify_report_definition(
ReportName,
ReportDefinition
)
ReportName |
[required] The name of the report that you want to create. The name must be unique, is case sensitive, and can't include spaces. |
ReportDefinition |
[required] The definition of Amazon Web Services Cost and Usage Report. You can specify the report name, time unit, report format, compression format, S3 bucket, additional artifacts, and schema elements in the definition. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.