batch_meter_usage is called from a SaaS application listed on AWS Marketplace to post metering records for a set of customers.
See https://www.paws-r-sdk.com/docs/marketplacemetering_batch_meter_usage/ for full documentation.
marketplacemetering_batch_meter_usage(UsageRecords, ProductCode)[required] The set of UsageRecords to submit.
batch_meter_usage accepts up
to 25 UsageRecords at a time.
[required] Product code is used to uniquely identify a product in AWS Marketplace. The product code should be the same as the one used during the publishing of a new product.