View source: R/marketplacemetering_operations.R
| marketplacemetering_batch_meter_usage | R Documentation |
Amazon Web Services Marketplace is introducing Concurrent Agreements, enabling buyers to make multiple purchases per Amazon Web Services account. Starting June 1, 2026, new SaaS products must use CustomerAWSAccountId (instead of CustomerIdentifier), LicenseArn (instead of ProductCode) to support this feature. Existing integrations will continue to work. Review the new integration for Concurrent Agreements here.
See https://www.paws-r-sdk.com/docs/marketplacemetering_batch_meter_usage/ for full documentation.
marketplacemetering_batch_meter_usage(UsageRecords, ProductCode = NULL)
UsageRecords |
[required] The set of |
ProductCode |
Product code is used to uniquely identify a product in Amazon Web Services Marketplace. The product code should be the same as the one used during the publishing of a new product. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.