View source: R/marketplacemetering_operations.R
| marketplacemetering_meter_usage | R Documentation |
As a seller, your software hosted in the buyer's Amazon Web Services account uses this API action to emit metering records directly to Amazon Web Services Marketplace. You must use the following buyer Amazon Web Services account credentials to sign the API request.
See https://www.paws-r-sdk.com/docs/marketplacemetering_meter_usage/ for full documentation.
marketplacemetering_meter_usage(
ProductCode,
Timestamp,
UsageDimension,
UsageQuantity = NULL,
DryRun = NULL,
UsageAllocations = NULL,
ClientToken = NULL
)
ProductCode |
[required] Product code is used to uniquely identify a product in Amazon Web Services Marketplace. The product code should be the same as the one used during the publishing of a new product. |
Timestamp |
[required] Timestamp, in UTC, for which the usage is being reported. Your application can meter usage for up to six hours in the past. Make sure the |
UsageDimension |
[required] It will be one of the fcp dimension name provided during the publishing of the product. |
UsageQuantity |
Consumption value for the hour. Defaults to |
DryRun |
Checks whether you have the permissions required for the action, but does not make the request. If you have the permissions, the request returns |
UsageAllocations |
The set of The sum of all |
ClientToken |
Specifies a unique, case-sensitive identifier that you provide to ensure the idempotency of the request. This lets you safely retry the request without accidentally performing the same operation a second time. Passing the same value to a later call to an operation requires that you also pass the same value for all other parameters. We recommend that you use a UUID type of value. If you don't provide this value, then Amazon Web Services generates a random one for you. If you retry the operation with the same |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.