View source: R/paymentcryptographycontrolplane_operations.R
| paymentcryptographycontrolplane_add_key_replication_regions | R Documentation |
Adds replication Amazon Web Services Regions to an existing Amazon Web Services Payment Cryptography key, enabling the key to be used for cryptographic operations in additional Amazon Web Services Regions.
See https://www.paws-r-sdk.com/docs/paymentcryptographycontrolplane_add_key_replication_regions/ for full documentation.
paymentcryptographycontrolplane_add_key_replication_regions(
KeyIdentifier,
ReplicationRegions
)
KeyIdentifier |
[required] The key identifier (ARN or alias) of the key for which to add replication regions. This key must exist and be in a valid state for replication operations. |
ReplicationRegions |
[required] The list of Amazon Web Services Regions to add to the key's replication configuration. Each region must be a valid Amazon Web Services Region where Amazon Web Services Payment Cryptography is available. The key will be replicated to these regions, allowing cryptographic operations to be performed closer to your applications. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.