| paymentcryptographycontrolplane_disable_default_key_replication_regions | R Documentation |
Disables Multi-Region key replication settings for the specified Amazon Web Services Regions in your Amazon Web Services account, preventing new keys from being automatically replicated to those regions.
See https://www.paws-r-sdk.com/docs/paymentcryptographycontrolplane_disable_default_key_replication_regions/ for full documentation.
paymentcryptographycontrolplane_disable_default_key_replication_regions(
ReplicationRegions
)
ReplicationRegions |
[required] The list of Amazon Web Services Regions to remove from the account's default replication regions. New keys created after this operation will not automatically be replicated to these regions, though existing keys with replication to these regions will be unaffected. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.