View source: R/paymentcryptographycontrolplane_operations.R
| paymentcryptographycontrolplane_disassociate_mpa_team | R Documentation |
Removes the association between a Multi-Party Approval (MPA) team and a protected operation.
See https://www.paws-r-sdk.com/docs/paymentcryptographycontrolplane_disassociate_mpa_team/ for full documentation.
paymentcryptographycontrolplane_disassociate_mpa_team(
Action,
RequesterComment = NULL
)
Action |
[required] The protected operation to disassociate from the MPA team. Currently, the only supported value is |
RequesterComment |
The comment from the requester explaining the reason for the disassociation. Don't include personal, confidential or sensitive information in this field. This field may be displayed in plaintext in CloudTrail logs and other output. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.