| paymentcryptographycontrolplane_enable_default_key_replication_regions | R Documentation |
Enables Multi-Region key replication settings for your Amazon Web Services account, causing new keys to be automatically replicated to the specified Amazon Web Services Regions when created.
See https://www.paws-r-sdk.com/docs/paymentcryptographycontrolplane_enable_default_key_replication_regions/ for full documentation.
paymentcryptographycontrolplane_enable_default_key_replication_regions(
ReplicationRegions
)
ReplicationRegions |
[required] The list of Amazon Web Services Regions to enable as default replication regions for the Amazon Web Services account for Multi-Region key replication. New keys created in this account will automatically be replicated to these regions unless explicitly overridden during key creation. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.