| paymentcryptographycontrolplane_get_default_key_replication_regions | R Documentation |
Retrieves the list of Amazon Web Services Regions where Multi-Region key replication is currently enabled for your Amazon Web Services account.
See https://www.paws-r-sdk.com/docs/paymentcryptographycontrolplane_get_default_key_replication_regions/ for full documentation.
paymentcryptographycontrolplane_get_default_key_replication_regions()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.