View source: R/paymentcryptographycontrolplane_operations.R
| paymentcryptographycontrolplane_get_key | R Documentation |
Gets the key metadata for an Amazon Web Services Payment Cryptography key, including the immutable and mutable attributes specified when the key was created. Returns key metadata including attributes, state, and timestamps, but does not return the actual cryptographic key material.
See https://www.paws-r-sdk.com/docs/paymentcryptographycontrolplane_get_key/ for full documentation.
paymentcryptographycontrolplane_get_key(KeyIdentifier)
KeyIdentifier |
[required] The |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.