View source: R/paymentcryptographycontrolplane_operations.R
| paymentcryptographycontrolplane_get_parameters_for_export | R Documentation |
Gets the export token and the signing key certificate to initiate a TR-34 key export from Amazon Web Services Payment Cryptography.
See https://www.paws-r-sdk.com/docs/paymentcryptographycontrolplane_get_parameters_for_export/ for full documentation.
paymentcryptographycontrolplane_get_parameters_for_export(
KeyMaterialType,
SigningKeyAlgorithm,
ReuseLastGeneratedToken = NULL
)
KeyMaterialType |
[required] The key block format type (for example, TR-34 or TR-31) to use during key material export. Export token is only required for a TR-34 key export, |
SigningKeyAlgorithm |
[required] The signing key algorithm to generate a signing key certificate. This certificate signs the wrapped key under export within the TR-34 key block. |
ReuseLastGeneratedToken |
Specifies whether to reuse the existing export token and signing key certificate. If set to |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.