View source: R/paymentcryptographycontrolplane_operations.R
| paymentcryptographycontrolplane_put_resource_policy | R Documentation |
Attaches or replaces a resource-based policy on an Amazon Web Services Payment Cryptography key. A resource-based policy can grant cross-account access to your key.
See https://www.paws-r-sdk.com/docs/paymentcryptographycontrolplane_put_resource_policy/ for full documentation.
paymentcryptographycontrolplane_put_resource_policy(ResourceArn, Policy)
ResourceArn |
[required] The |
Policy |
[required] The resource-based policy to attach to the key, in JSON format. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.