| paymentcryptographydataplane_generate_auth_request_cryptogram | R Documentation |
Generates an Authorization Request Cryptogram (ARQC) for an EMV chip payment card authorization. For more information, see Generate auth request cryptogram in the Amazon Web Services Payment Cryptography User Guide.
See https://www.paws-r-sdk.com/docs/paymentcryptographydataplane_generate_auth_request_cryptogram/ for full documentation.
paymentcryptographydataplane_generate_auth_request_cryptogram(
KeyIdentifier,
TransactionData,
MajorKeyDerivationMode,
SessionKeyDerivationAttributes
)
KeyIdentifier |
[required] The |
TransactionData |
[required] The transaction data that Amazon Web Services Payment Cryptography uses for ARQC generation. The same transaction data is used for ARQC verification by the issuer using |
MajorKeyDerivationMode |
[required] The method to use when deriving the major encryption key for ARQC generation within Amazon Web Services Payment Cryptography. |
SessionKeyDerivationAttributes |
[required] The attributes and values to use for deriving a session key for ARQC generation within Amazon Web Services Payment Cryptography. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.