View source: R/paymentcryptographydataplane_operations.R
| paymentcryptographydataplane_generate_as_2805_kek_validation | R Documentation |
Generates a KekValidationRequest or a KekValidationResponse for node-to-node initialization between payment processing nodes using Australian Standard 2805 (AS2805).
See https://www.paws-r-sdk.com/docs/paymentcryptographydataplane_generate_as_2805_kek_validation/ for full documentation.
paymentcryptographydataplane_generate_as_2805_kek_validation(
KeyIdentifier,
KekValidationType,
RandomKeySendVariantMask
)
KeyIdentifier |
[required] The |
KekValidationType |
[required] Defines whether to generate a KEK validation request or KEK validation response for node-to-node initialization. |
RandomKeySendVariantMask |
[required] The key variant to use for generating a random key for KEK validation during node-to-node initialization. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.