View source: R/paymentcryptographydataplane_operations.R
| paymentcryptographydataplane_translate_key_material | R Documentation |
Translates an cryptographic key between different wrapping keys without importing the key into Amazon Web Services Payment Cryptography.
See https://www.paws-r-sdk.com/docs/paymentcryptographydataplane_translate_key_material/ for full documentation.
paymentcryptographydataplane_translate_key_material(
IncomingKeyMaterial,
OutgoingKeyMaterial,
KeyCheckValueAlgorithm = NULL
)
IncomingKeyMaterial |
[required] Parameter information of the TR31WrappedKeyBlock containing the transaction key. |
OutgoingKeyMaterial |
[required] Parameter information of the wrapping key used to wrap the transaction key in the outgoing TR31WrappedKeyBlock. |
KeyCheckValueAlgorithm |
The key check value (KCV) algorithm used for calculating the KCV of the derived key. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.